// Copyright 2022 ESRI
//
// All rights reserved under the copyright laws of the United States
// and applicable international laws, treaties, and conventions.
//
// You may freely redistribute and use this sample code, with or
// without modification, provided you include the original copyright
// notice and use restrictions.
//
// See the Sample code usage restrictions document for further information.
//
#include "Display_a_scene.h"
#include "Scene.h"
#include "SceneQuickView.h"
#include <QUrl>

using namespace Esri::ArcGISRuntime;
Display_a_scene::Display_a_scene(QObject* parent /* = nullptr */):

    QObject(parent)

{
    setupScene();
}

Display_a_scene::~Display_a_scene()
{
}

SceneQuickView* Display_a_scene::sceneView() const
{
    return m_sceneView;
}

// Set the view (created in QML)
void Display_a_scene::setSceneView(SceneQuickView* sceneView)
{
    if (!sceneView || sceneView == m_sceneView)
    {
        return;
    }
    m_sceneView = sceneView;
    m_sceneView->setArcGISScene(m_scene);

    emit sceneViewChanged();
}

void Display_a_scene::setupScene()
{

    // Create an item_id to reference an item at a web server
    const QString item_id("579f97b2f3b94d4a8e48a5f140a6639b");

    // Create a QUrl from the web scene server URL and the item_id
    const QUrl portal_url(QString("https://arcgis.com/sharing/rest/content/items/" + item_id));

    // Create the scene, referencing the QUrl
    m_scene = new Scene(portal_url, this);

}
